@@ -126,9 +126,9 @@ Puppet::Type.type(:package).provide :gem, :parent => Puppet::Provider::Package::
     end
 
     if options[:justme]
-      return list.shift
+      list.shift
     else
-      return list
+      list
     end
   end
 
@@ -140,8 +140,8 @@ Puppet::Type.type(:package).provide :gem, :parent => Puppet::Provider::Package::
     # so we don't need to check for them
 
     if desc =~ /^(\S+)\s+\((.+)\)/
-      gem_name = $1
-      versions = $2.sub('default: ', '').split(/,\s*/)
+      gem_name = Regexp.last_match(1)
+      versions = Regexp.last_match(2).sub('default: ', '').split(/,\s*/)
       {
         :name => gem_name,
         :ensure => versions.map { |v| v.split[0] },
@@ -168,12 +168,10 @@ Puppet::Type.type(:package).provide :gem, :parent => Puppet::Provider::Package::
       end
 
       return is.any? do |version|
-        begin
-          should_range.include?(GEM_VERSION.parse(version))
-        rescue GEM_VERSION::ValidationFailure
-          Puppet.debug("Cannot parse #{version} as a ruby gem version")
-          false
-        end
+        should_range.include?(GEM_VERSION.parse(version))
+      rescue GEM_VERSION::ValidationFailure
+        Puppet.debug("Cannot parse #{version} as a ruby gem version")
+        false
       end
     end
 
@@ -211,7 +209,7 @@ Puppet::Type.type(:package).provide :gem, :parent => Puppet::Provider::Package::
     end
 
     if Puppet::Util::Platform.windows?
-      command_options << "-v" << %Q["#{should}"] if useversion && !should.is_a?(Symbol)
+      command_options << "-v" << %Q("#{should}") if useversion && !should.is_a?(Symbol)
     elsif useversion && !should.is_a?(Symbol)
       command_options << "-v" << should
     end
@@ -238,14 +236,14 @@ Puppet::Type.type(:package).provide :gem, :parent => Puppet::Provider::Package::
         command_options << uri.path
       when 'puppet'
         # we don't support puppet:// URLs (yet)
-        raise Puppet::Error.new(_("puppet:// URLs are not supported as gem sources"))
+        raise Puppet::Error, _("puppet:// URLs are not supported as gem sources")
       else
         # check whether it's an absolute file path to help Windows out
         if Puppet::Util.absolute_path?(source)
           command_options << source
         else
           # interpret it as a gem repository
-          command_options << "--source" << "#{source}" << resource[:name]
+          command_options << "--source" << source.to_s << resource[:name]
         end
       end
     else
@@ -284,7 +282,7 @@ Puppet::Type.type(:package).provide :gem, :parent => Puppet::Provider::Package::
   end
 
   def update
-    self.install(false)
+    install(false)
   end
 
   def install_options
