@@ -1,8 +1,10 @@
+# frozen_string_literal: true
+
 module Puppet::Scheduler
   class Timer
     def wait_for(seconds)
       if seconds > 0
-        select([], [], [], seconds)
+        sleep(seconds)
       end
     end
 
