@@ -1,4 +1,6 @@
-require 'puppet/util/profiler/logging'
+# frozen_string_literal: true
+
+require_relative '../../../puppet/util/profiler/logging'
 
 # A profiler implementation that measures the number of seconds a segment of
 # code takes to execute and provides a callback with a string representation of
@@ -6,13 +8,13 @@ require 'puppet/util/profiler/logging'
 #
 # @api private
 class Puppet::Util::Profiler::WallClock < Puppet::Util::Profiler::Logging
-  def start
+  def do_start(description, metric_id)
     Timer.new
   end
 
-  def finish(context)
-    context.stop
-    "took #{context} seconds"
+  def do_finish(context, description, metric_id)
+    { :time => context.stop,
+      :msg => _("took %{context} seconds") % { context: context } }
   end
 
   class Timer
@@ -23,12 +25,12 @@ class Puppet::Util::Profiler::WallClock < Puppet::Util::Profiler::Logging
     end
 
     def stop
-      @finish = Time.now
+      @time = Time.now - @start
+      @time
     end
 
     def to_s
-      format(FOUR_DECIMAL_DIGITS, @finish - @start)
+      format(FOUR_DECIMAL_DIGITS, @time)
     end
   end
 end
-
